@@ -16,6 +16,7 @@ from .core import sigma_func
 
 from astropy.nddata import CCDData, StdDevUncertainty
 from astropy.stats import sigma_clip
+from astropy.utils import deprecated_renamed_argument
 from astropy import log
 
 __all__ = ['Combiner', 'combine']
@@ -294,9 +295,13 @@ class Combiner:
             self.data_arr.mask[mask] = True
 
     # set up sigma  clipping algorithms
+    @deprecated_renamed_argument('use_astropy', None, arg_in_kwargs=True,
+                                 since='2.4.0',
+                                 message='The use_astropy argument has been removed because '
+                                         'astropy sigma clipping is now always used.'
+                                 )
     def sigma_clipping(self, low_thresh=3, high_thresh=3,
-                       func=ma.mean, dev_func=ma.std, use_astropy=False,
-                       **kwd):
+                       func='mean', dev_func='std', **kwd):
         """
         Pixels will be rejected if they have deviations greater than those
         set by the threshold values. The algorithm will first calculated
@@ -307,6 +312,7 @@ class Combiner:
 
         Parameters
         -----------
+
         low_thresh : positive float or None, optional
             Threshold for rejecting pixels that deviate below the baseline
             value. If negative value, then will be convert to a positive
@@ -318,54 +324,40 @@ class Combiner:
             value. If None, no rejection will be done based on high_thresh.
             Default is 3.
 
-        func : function, optional
-            Function for calculating the baseline values (i.e. `numpy.ma.mean`
-            or `numpy.ma.median`). This should be a function that can handle
-            `numpy.ma.MaskedArray` objects. **Set to ``'median'`` and
-            set ``use_astropy=True`` for best performance if using a
-            median.**
-            Default is `numpy.ma.mean`.
+        func : {'median', 'mean'} or callable, optional
+            The statistic or callable function/object used to compute
+            the center value for the clipping. If using a callable
+            function/object and the ``axis`` keyword is used, then it must
+            be able to ignore NaNs (e.g., `numpy.nanmean`) and it must have
+            an ``axis`` keyword to return an array with axis dimension(s)
+            removed. The default is ``'median'``.
 
-        dev_func : function, optional
-            Function for calculating the deviation from the baseline value
-            (i.e. `numpy.ma.std`). This should be a function that can handle
-            `numpy.ma.MaskedArray` objects.
-            Default is `numpy.ma.std`.
+        dev_func : {'std', 'mad_std'} or callable, optional
+            The statistic or callable function/object used to compute the
+            standard deviation about the center value. If using a callable
+            function/object and the ``axis`` keyword is used, then it must
+            be able to ignore NaNs (e.g., `numpy.nanstd`) and it must have
+            an ``axis`` keyword to return an array with axis dimension(s)
+            removed. The default is ``'std'``.
 
-        use_astropy : bool, optional
-            If ``True``, use astropy's `~astropy.stats.sigma_clip`, which is faster
-            and more flexible. The high/low sigma clip parameters are set
-            from ``low_thresh`` and ``high_thresh``. Any remaining keywords are passed
-            in to astropy's `~astropy.stats.sigma_clip`. By default, the
-            number of iterations and other settings will be made to reproduce
-            the behavior of ccdproc's ``sigma_clipping``.
+        kwd
+            Any remaining keyword arguments are passed to astropy's
+            :func:`~astropy.stats.sigma_clip` function.
         """
-        if use_astropy:
-            copy = kwd.get('copy', False)
-            axis = kwd.get('axis', 0)
-            maxiters = kwd.get('maxiters', 1)
-            self.data_arr.mask = \
-                sigma_clip(self.data_arr.data, sigma_lower=low_thresh,
-                           sigma_upper=high_thresh, axis=axis, copy=copy,
-                           maxiters=maxiters,
-                           cenfunc=func, stdfunc=dev_func,
-                           masked=True,
-                           **kwd).mask
-            return
 
-        # setup baseline values
-        baseline = func(self.data_arr, axis=0)
-        dev = dev_func(self.data_arr, axis=0)
-        # reject values
-        if low_thresh is not None:
-            # check for negative numbers in low_thresh
-            if low_thresh < 0:
-                low_thresh = abs(low_thresh)
-            mask = (self.data_arr - baseline < -low_thresh * dev)
-            self.data_arr.mask[mask] = True
-        if high_thresh is not None:
-            mask = (self.data_arr - baseline > high_thresh * dev)
-            self.data_arr.mask[mask] = True
+        # Remove in 3.0
+        _ = kwd.pop('use_astropy', True)
+
+        self.data_arr.mask = sigma_clip(self.data_arr.data,
+                                        sigma_lower=low_thresh,
+                                        sigma_upper=high_thresh,
+                                        axis=kwd.get('axis', 0),
+                                        copy=kwd.get('copy', False),
+                                        maxiters=kwd.get('maxiters', 1),
+                                        cenfunc=func,
+                                        stdfunc=dev_func,
+                                        masked=True,
+                                        **kwd).mask
 
     def _get_scaled_data(self, scale_arg):
         if scale_arg is not None:
@@ -710,7 +702,8 @@ def combine(img_list, output_file=None,
             sigma_clip=False,
             sigma_clip_low_thresh=3, sigma_clip_high_thresh=3,
             sigma_clip_func=ma.mean, sigma_clip_dev_func=ma.std,
-            dtype=None, combine_uncertainty_function=None, **ccdkwargs):
+            dtype=None, combine_uncertainty_function=None,
+            overwrite_output=False, **ccdkwargs):
     """
     Convenience function for combining multiple images.
 
@@ -807,6 +800,12 @@ def combine(img_list, output_file=None,
         sum combine, otherwise use the function provided.
         Default is ``None``.
 
+    overwrite_output : bool, optional
+        If ``output_file`` is specified, this is passed to the
+        `astropy.nddata.fits_ccddata_writer` under the keyword ``overwrite``;
+        has no effect otherwise.
+        Default is ``False``.
+
     ccdkwargs : Other keyword arguments for `astropy.nddata.fits_ccddata_reader`.
 
     Returns
@@ -978,6 +977,6 @@ def combine(img_list, output_file=None,
 
     # Write fits file if filename was provided
     if output_file is not None:
-        ccd.write(output_file)
+        ccd.write(output_file, overwrite=overwrite_output)
 
     return ccd
