@@ -5,7 +5,7 @@
 import math
 import numbers
 import logging
-import packaging
+from packaging import version as pkgversion
 import warnings
 
 import numpy as np
@@ -844,7 +844,7 @@ def transform_image(ccd, transform_func, **kwargs):
     The syntax for transforming the array using
     `scipy.ndimage.shift`::
 
-        >>> from scipy.ndimage.interpolation import shift
+        >>> from scipy.ndimage import shift
         >>> from ccdproc import transform_image
         >>> transformed = transform_image(arr1, shift, shift=(5.5, 8.1))
     """
@@ -875,7 +875,7 @@ def transform_image(ccd, transform_func, **kwargs):
 
     if nccd.wcs is not None:
         warn = 'WCS information may be incorrect as no transformation was applied to it'
-        logging.warning(warn)
+        warnings.warn(warn, UserWarning)
 
     return nccd
 
@@ -1518,8 +1518,8 @@ def cosmicray_lacosmic(ccd, sigclip=4.5, sigfrac=0.3,
         readnoise = readnoise * u.electron
 
     # Handle transition from old astroscrappy interface to new
-    old_astroscrappy_interface = (packaging.version.parse(asy_version) <
-                                  packaging.version.parse('1.1.0'))
+    old_astroscrappy_interface = (pkgversion.parse(asy_version) <
+                                  pkgversion.parse('1.1.0'))
 
     # Use this dictionary to define which keyword arguments are actually
     # passed to astroscrappy.
